
#include <iostream>
#include <ctime>
#include <fstream>
#include <string>

#include "CustomFiberThread.h"


CustomFiberThread::CustomFiberThread()
{
	fixedMoney = 0;
	tipPercent = 0.0f;
	tipDecrement = 0.0f;
	totalMoney = 0;
	carHealth = 0.0f;
	totalFares = 0;
	nextNitro = 0;

	taxiStartTimer =0;
	taxiStopTimer =0;
	taxiNoFareTimer = 0;
	taxiDescTimer = 0;
	taxiCompleteTimer = 0;
	pickThemUpTimer = 0;

	displayedCredits = false;
	showCoords = false;

	SetName("CustomFiberThread");

	currentState = STATE_PLAYER_NOT_IN_TAXI;

	pedManager = PedManager();

	coordManager = CoordManager();

	coordManager.placeCoords();

	setState(currentState);
}

void CustomFiberThread::SpawnCar(eModel model)
{
	RequestModel(model);

	while(!HasModelLoaded(model))
	{
		Wait(0);
	}

	Ped ped = Scripting::GetPlayerPed();

	Vehicle vehicle;
	f32 x,y,z;

	GetCharCoordinates(ped, &x, &y, &z);

	CreateCar(model, x, y, z, &vehicle, true);

	MarkModelAsNoLongerNeeded(model);

	TaskWarpCharIntoCarAsDriver(Scripting::GetPlayerPed(),vehicle);

}

bool CustomFiberThread::deadOrArrested() const
{
	return(IsPlayerDead(Scripting::GetPlayer()) || IsPlayerBeingArrested() || !IsPlayerPlaying(Scripting::GetPlayer()));
}

void CustomFiberThread::setTextProps( u32 font,f32 wrapX,f32 wrapY, u32 type,u32 extra1,u32 extra2,u32 extra3,u32 extra4,u32 extra5 ) const
{
	SetTextFont(font);
	SetTextBackground(false);
	SetTextDropshadow(0, 0, 0, 0, 255);
	SetTextEdge(0, 0, 0, 0, 255);
	switch (type)
	{
	case 1:
		{
			SetTextBackground(true);
			break;
		}
	case 2:
		{
			SetTextDropshadow(extra1, extra2, extra3, extra4, extra5);
			break;
		}
	case 3:
		{
			SetTextEdge(extra1, extra2, extra3, extra4, extra5);
			break;
		}
	}
	SetTextProportional(true);
	SetTextWrap(wrapX, wrapY);
}

bool CustomFiberThread::drivingTaxi() const
{
	if(IsCharInAnyCar(Scripting::GetPlayerPed())){
		Car cv;
		GetCarCharIsUsing(Scripting::GetPlayerPed(), &cv);
		eModel model;
		GetCarModel(cv, &model);
		if(model == MODEL_TAXI || model == MODEL_TAXI2 || model == MODEL_CABBY || model == MODEL_ROM){ //possible taxi model IDs
			Ped pPed;
			GetDriverOfCar(cv, &pPed);
			if(pPed == Scripting::GetPlayerPed()){
				return true;
			}
		}
	}
	return false;
}

void CustomFiberThread::checkKeys(){
	if(IsGameKeyboardKeyJustPressed(18)){ //E
		if(currentState >= STATE_IN_TAXI_BEFORE_MISSIONS){
			taxiStartTimer = TimerA()+5000;
			if(currentState >= 2){
				setState(STATE_PLAYER_NOT_IN_TAXI);
			}
			else if(currentState == 1){
				Scripting::Ped p = Ped();
				pedManager.getPed(&p);
				if(!DoesCharExist(p)){
					taxiStopTimer = TimerA()+5000;
					taxiNoFareTimer = TimerA()+10000;
					setState(STATE_MISSIONS_STARTED_NO_PED);
				}
			}
		}
	}
}

void CustomFiberThread::displayText( const ch *toDisp,u32 flag ) const
{
	switch(flag){
		case 0:
			SetTextScale(0.3f, 0.4f);
			setTextProps(0, 0.06f, 0.3f, 3, 1, 0, 0, 0, 255);
			DisplayTextWithLiteralString(0.06f,0.06f,"STRTNM1",toDisp);
			break;
		case 1:
			SetTextScale(0.3f, 0.4f);
			setTextProps(0,0.3f,0.8f,3,1,0,0,0,255);
			DisplayTextWithLiteralString(0.3f,0.8f,"STRTNM1",toDisp);
			break;
		case 2:
			SetTextScale(0.3f,0.4f);
			setTextProps(0,0.773f,0.95f,3,1,0,0,0,255);
			DisplayTextWithLiteralString(0.773f,0.195f,"STRTNM1",toDisp);
			break;
		case 3:
			setTextProps(5,0.25f,0.95f,3,1,0,0,0,255);
			DisplayTextWithLiteralString(0.25f,0.40f,"STRTNM1",toDisp);
	}
}

void CustomFiberThread::setTarget(f32 x,f32 y,f32 z){
	clearTarget();

	eModel m = MODEL_CJ_ARROW;

	if(!HasModelLoaded(m))
		RequestModel(m);

	while(!HasModelLoaded(m)){
		Wait(1);
	}
	f32 pX,pY,pZ;
	pX= x;
	pY = y;
	pZ = z;
	pZ -= 0.9f;
	Scripting::CreateObject(m,pX,pY+1.1f,pZ,&targetObject,false);
	Scripting::SetObjectScale(targetObject,2.0f);

	AddBlipForCoord(x,y,z,&tarBlip);
	ChangeBlipColour(tarBlip,5);
	SetRoute(tarBlip,true);
}
void CustomFiberThread::clearTarget(){
	SetRoute(tarBlip,false);
	if(DoesBlipExist(tarBlip)){
		RemoveBlip(tarBlip);
	}
}
void CustomFiberThread::doBonus(){
	SpawnCar(MODEL_TAXI);

	/* dunno how to do this
	Vehicle veh;
	Scripting::GetCarCharIsUsing(Scripting::GetPlayerPed(),&veh);

	if(Scripting::DoesVehicleExist(veh)){
		for(int i=0;i<10;i++){
			NativeInvoke::Invoke<ScriptVoid>("TURN_OFF_VEHICLE_EXTRA", veh, i, 0);
		}
	}
	*/
}

void CustomFiberThread::setState(int s){
	if(s == currentState)
		return;

	if(s == STATE_PLAYER_NOT_IN_TAXI)
		totalCleanUp();

	currentState = s;
	pedManager.setState(s);
}
void CustomFiberThread::totalCleanUp(){
	totalFares = 0;
	fixedMoney = 0;
	tipPercent = 0.0f;

	//if there is a coord, erase it.
	clearTarget();
	//if there is a ped, erase it.
	pedManager.cleanUp();
}
void CustomFiberThread::addMoney( int amount )
{
	//IncrementFloatStatNoMessage(STAT_CURRENT_MONEY,(float)amount);
	AddScore(Scripting::GetPlayer(),amount);
	//SetCharMoney(Scripting::GetPlayerPed(),amount);	
	DisplayCash(true);
}

void CustomFiberThread::update(){
	Ped ped;
	f32 playerX,playerY,playerZ;
	GetCharCoordinates(Scripting::GetPlayerPed(),&playerX,&playerY,&playerZ);
	
	f32 tarX,tarY,tarZ;
	f32 dist;
	Car cv;
	char comp[200],comp2[200];

	pedManager.update();
	if(currentState >= STATE_MISSIONS_STARTED_NO_PED){
		char custText[200];
		if(totalFares>0)
			if(tipPercent>0.0f)
				sprintf_s(custText,200,"Customers: %d~n~Earned: $%d~n~TIP:",totalFares,totalMoney);
			else
				sprintf_s(custText,200,"Customers: %d~n~Earned: $%d",totalFares,totalMoney);
		else
			if(tipPercent>0.0f)
				sprintf_s(custText,200," ~n~ ~n~TIP:");
			else
				sprintf_s(custText,200," ");
		displayText(custText,2);
	}
	switch(currentState){
		case STATE_PLAYER_NOT_IN_TAXI://outside taxi
			stopSpray();
			if(!deadOrArrested() && !GetMissionFlag() && drivingTaxi()){
				taxiStartTimer=TimerA()+5000;
				setState(STATE_IN_TAXI_BEFORE_MISSIONS);
			}
			break;
		case STATE_IN_TAXI_BEFORE_MISSIONS://inside taxi, didn't start missions.
			if(deadOrArrested() || GetMissionFlag() || !drivingTaxi()){
				setState(STATE_PLAYER_NOT_IN_TAXI);
				break;
			}
			stopSpray();

			GetCarCharIsUsing(Scripting::GetPlayerPed(),&cv);
			SetTaxiLights(cv,false);

			if(TimerA()<taxiStartTimer)
				displayText("Press E to start the taxi missions.",0);

			break;
		case STATE_MISSIONS_STARTED_NO_PED://inside taxi, missions started, but no ped around.
			tipPercent = 0.0f;

			if(!displayedCredits){
				while(TimerA()<taxiStopTimer){
					Wait(1);
					displayText("Taxi missions mod by Hergonan and ObsessedWithGTA4 activated.",1);
					displayText("~n~~n~--OPEN BETA!--",1);
				}
				displayedCredits = true;
				taxiStopTimer = TimerA()+5000;
			}

			if(deadOrArrested() || GetMissionFlag() || !drivingTaxi()){
				setState(STATE_PLAYER_NOT_IN_TAXI);
				break;
			}

			GetCarCharIsUsing(Scripting::GetPlayerPed(),&cv);
			SetTaxiLights(cv,true);
			if(TimerA()<taxiStopTimer)
				displayText("Press E to stop the taxi missions.",0);

			carHealth = GetEngineHealth(cv);
			if(carHealth == 0.0f)
				carHealth = 1000.0f;
			if(carHealth != NULL && carHealth <= 300.0f){
				displayText("Your car is trashed. Get it repaired.",1);
				displaySpray();
				break;
			}
			else{
				stopSpray();
			}
			if(TimerA()<taxiNoFareTimer)
				displayText("There are no customers around. Check another location.",1);

			pedManager.checkPeds();
			ped = Ped();
			pedManager.getPed(&ped);
			if(DoesCharExist(ped)){
				pickThemUpTimer = TimerA()+10000;
				setState(STATE_PED_OUTSIDE);
			}

			break;
		case STATE_PED_OUTSIDE://inside taxi, missions started, ped outside.
			tipPercent = 0.0f;

			if(!HaveAnimsLoaded("AMB@TAXI_HAIL_M"))
				RequestAnims("AMB@TAXI_HAIL_M");
			if(!HaveAnimsLoaded("AMB@TAXI_HAIL_F"))
				RequestAnims("AMB@TAXI_HAIL_F");

			if(deadOrArrested() || GetMissionFlag() || !drivingTaxi()){
				setState(STATE_PLAYER_NOT_IN_TAXI);
				break;
			}

			GetCarCharIsUsing(Scripting::GetPlayerPed(),&cv);
			carHealth = GetEngineHealth(cv);
			if(carHealth != NULL && carHealth <= 150.0f){
				pedManager.cleanUp();
				taxiNoFareTimer = TimerA()+10000;
				setState(STATE_MISSIONS_STARTED_NO_PED);
				break;
			}

			ped = Ped();
			pedManager.getPed(&ped);
			if(!DoesCharExist(ped)){
				taxiNoFareTimer = TimerA()+10000;
				setState(STATE_MISSIONS_STARTED_NO_PED);
				break;
			}

			if(TimerA()<taxiStopTimer)
				displayText("Press E to stop the taxi missions.",0);
			if(TimerA()<pickThemUpTimer){
				if(Scripting::IsCharMale(ped))
					displayText("Stop close to the ~y~customer~s~ to pick him up.",1);
				else
					displayText("Stop close to the ~y~customer~s~ to pick her up.",1);

			}


			if(pedManager.getState() == PEDSTATE_MOVING_TO_TAXI){
				setState(STATE_PED_MOVING_TO_TAXI);
			}
			else if(pedManager.getState() == PEDSTATE_INSIDE_TAXI){
				setState(STATE_BEFORE_DESTINATION_SET);
			}
			break;
		case STATE_PED_MOVING_TO_TAXI://inside taxi, missions started, ped moving to a car.
			tipPercent = 0.0f;

			if(TimerA()<taxiStopTimer)
				displayText("Press E to stop the taxi missions.",0);

			if(deadOrArrested() || GetMissionFlag() || !drivingTaxi()){
				setState(STATE_PLAYER_NOT_IN_TAXI);
				break;
			}


			GetCarCharIsUsing(Scripting::GetPlayerPed(),&cv);
			carHealth = GetEngineHealth(cv);
			if(carHealth != NULL && carHealth <= 150.0f){
				pedManager.cleanUp();
				taxiNoFareTimer = TimerA()+10000;
				setState(STATE_MISSIONS_STARTED_NO_PED);
				break;
			}

			ped = Ped();
			pedManager.getPed(&ped);
			if(!DoesCharExist(ped)){
				taxiNoFareTimer = TimerA()+10000;
				setState(STATE_MISSIONS_STARTED_NO_PED);
				break;
			}
			if(pedManager.getState() == 2){
				setState(STATE_BEFORE_DESTINATION_SET);
			}
			else if(pedManager.getState() == 0){
				taxiNoFareTimer = TimerA()+10000;
				setState(STATE_MISSIONS_STARTED_NO_PED);
			}
			break;
		case STATE_BEFORE_DESTINATION_SET://inside taxi, missions started, ped inside the car, no coordinates shown.

			if(TimerA()<taxiStopTimer)
				displayText("Press E to stop the taxi missions.",0);
			if(deadOrArrested() || GetMissionFlag() || !drivingTaxi()){
				setState(STATE_PLAYER_NOT_IN_TAXI);
				break;
			}


			ped = Ped();
			pedManager.getPed(&ped);
			if(!DoesCharExist(ped)){
				taxiNoFareTimer = TimerA()+10000;
				setState(STATE_MISSIONS_STARTED_NO_PED);
				break;
			}
			GetCarCharIsUsing(Scripting::GetPlayerPed(),&cv);
			carHealth = GetEngineHealth(cv);
			SetTaxiLights(cv,false);
			if(carHealth != NULL && carHealth<=150.0f){
				pedManager.cleanUp();
				clearTarget();
				taxiNoFareTimer = TimerA()+10000;
				setState(STATE_MISSIONS_STARTED_NO_PED);
				break;
			}
			coord = coordManager.getRandomCoord(GetCharMoney(ped));
			coord.getCoord(&tarX,&tarY,&tarZ);
			setTarget(tarX,tarY,tarZ);
			taxiDescTimer = TimerA()+10000;
			tipPercent = 1.0f;				
			Scripting::GetDistanceBetweenCoords3D(playerX,playerY,playerZ,tarX,tarY,tarZ,&dist);
			fixedMoney = (int)(dist*0.05);

			tipDecrement = (0.4f/(dist+200.0f));

			tipPercent = 1.0f;
			setState(STATE_COORDS_SHOWN);
			break;
		case STATE_COORDS_SHOWN://inside taxi, missions started, ped inside the car, coordinates shown.
			char toDisp[500];
			if(TimerA()<taxiStopTimer)
				displayText("Press E to stop the taxi missions.",0);
			if(TimerA()<taxiDescTimer){
				char dest[400];
				coord.getDescr(dest);
				sprintf_s(toDisp,500,"Take the customer to ~y~%s",dest);
				displayText(toDisp,1);
			}

			if(deadOrArrested() || GetMissionFlag() || !drivingTaxi()){
				setState(STATE_PLAYER_NOT_IN_TAXI);
				break;
			}
			updateTip();
			ped = Ped();
			pedManager.getPed(&ped);
			if(!DoesCharExist(ped)){
				clearTarget();
				taxiNoFareTimer = TimerA()+10000;
				setState(STATE_MISSIONS_STARTED_NO_PED);
				break;
			}
			coord.getCoord(&tarX,&tarY,&tarZ);
			DrawLightWithRange(tarX,tarY,tarZ,0,255,0,10.0f,255.0f);
			GetDistanceBetweenCoords3D(tarX,tarY,tarZ,playerX,playerY,playerZ,&dist);
			if(dist<3.5f){
				setState(STATE_ON_TOP_OF_COORDS);
			}
			break;
		case STATE_ON_TOP_OF_COORDS://inside taxi, missions started, on top of the coordinates, ped inside the car.
			if(deadOrArrested() || GetMissionFlag() || !drivingTaxi()){
				setState(STATE_PLAYER_NOT_IN_TAXI);
				break;
			}
			ped = Ped();
			pedManager.getPed(&ped);
			if(!DoesCharExist(ped)){
				clearTarget();
				taxiNoFareTimer = TimerA()+10000;
				setState(STATE_MISSIONS_STARTED_NO_PED);
				break;
			}
			drawTip();
			coord.getCoord(&tarX,&tarY,&tarZ);
			DrawLightWithRange(tarX,tarY,tarZ,0,255,0,10.0f,22.0f);
			GetDistanceBetweenCoords3D(tarX,tarY,tarZ,playerX,playerY,playerZ,&dist);
			if(dist<3.5f){
				GetCarCharIsUsing(GetPlayerPed(), &cv);
				f32 speed;
				Scripting::GetCarSpeed(cv,&speed);
				if(speed>=5.0f){
					if(Scripting::IsVehicleOnAllWheels(cv)){
						Scripting::SetCarForwardSpeed(cv,speed/2);
					}
				}
				else{
					if(tipPercent>0.0f && (int)(fixedMoney*tipPercent*0.5) > 0){
						sprintf_s(comp,200,"JOB COMPLETE! ~y~$%d~s~~n~SPEED BONUS! ~y~$%d~s~",fixedMoney,(int)(fixedMoney*tipPercent*0.5));
						totalMoney += (int)(fixedMoney+(fixedMoney*tipPercent*0.5));
						addMoney((int)(fixedMoney+(fixedMoney*tipPercent*0.5)));
					}
					else{
						sprintf_s(comp,200,"JOB COMPLETE! ~y~$%d~s~",fixedMoney);
						addMoney(fixedMoney);
						totalMoney += fixedMoney;
					}

					SayAmbientSpeech(ped,"THANKS",true,false,false);
					save(loadSaved()+1);
					tipPercent = 0.0f;
					TriggerMissionCompleteAudio(true);
					pedManager.cleanUp();
					setState(STATE_PED_EXITING_CAR);
				}
			}
			else{
				setState(STATE_COORDS_SHOWN);
			}
			break;
		case STATE_PED_EXITING_CAR://inside taxi, missions started, on top of the coordinates, ped moving out of the car.
			if(deadOrArrested() || GetMissionFlag() || !drivingTaxi()){
				setState(STATE_PLAYER_NOT_IN_TAXI);
				break;
			}
			displayText(comp,3);
			coord.getCoord(&tarX,&tarY,&tarZ);
			DrawLightWithRange(tarX,tarY,tarZ,0,255,0,10.0f,22.0f);//can't display models... so I have to draw a light instead :(
			GetCarCharIsUsing(GetPlayerPed(), &cv);
			Scripting::SetCarForwardSpeed(cv,0);
			pedManager.cleanUp();
			ped = Ped();
			pedManager.getPed(&ped);
			if(!DoesCharExist(ped)){
				clearTarget();
				totalFares++;
				if(totalFares%5 == 0){
					sprintf_s(comp2,200,"%s~n~%d IN A ROW BONUS! $%d",comp,totalFares,totalFares*10);
					addMoney(totalFares*10);
				}

				taxiCompleteTimer = TimerA()+5000;
				setState(STATE_MISSION_COMPLETE);
			}
			break;

		case STATE_MISSION_COMPLETE://inside taxi, missions started, on top of the coordinates, ped out of the car.
			if(deadOrArrested() || GetMissionFlag() || !drivingTaxi()){
				setState(STATE_PLAYER_NOT_IN_TAXI);
				break;
			}
			if(totalFares%5==0){
				displayText(comp2,3);
			}
			else
				displayText(comp,3);
			if(TimerA()>=taxiCompleteTimer){
				taxiNoFareTimer = TimerA()+10000;
				setState(STATE_MISSIONS_STARTED_NO_PED);
			}
			break;
	}
}

void CustomFiberThread::displaySpray(){
	//SwitchOffWaypoint();
	if(!DoesBlipExist(sprayBlip)){
		f32 x,y,z;
		Coord sprayCoord = coordManager.getClosestSpray();
		sprayCoord.getCoord(&x,&y,&z);
		AddBlipForCoord(x,y,z,&sprayBlip);
		Scripting::ChangeBlipSprite(sprayBlip,BLIP_PAY_N_SPRAY);
		Scripting::ChangeBlipColour(sprayBlip,(ColourIndex)1);
		FlashBlip(sprayBlip,true);
		Scripting::FlashBlipAlt(sprayBlip,true);
		SetRoute(sprayBlip,true);
	}
}

void CustomFiberThread::stopSpray(){
	SetRoute(sprayBlip,false);
	if(DoesBlipExist(sprayBlip)){
		RemoveBlip(sprayBlip);
		if(DoesBlipExist(tarBlip))
			SetRoute(tarBlip,true);
	}
}

void CustomFiberThread::drawTip() const
{
	DrawRect(0.81f+0.07f, 0.25f+0.015f, 0.14f, 0.03f, 0, 0, 0, 255);
	DrawRect(0.82f+0.06f, 0.26f+0.005f, 0.12f, 0.02f,86,101,120,255);
	DrawRect(0.82f+(0.06f*tipPercent), 0.26f+0.005f, 0.12f*tipPercent, 0.02f,255,248,50,255);
}

void CustomFiberThread::updateTip(){
	Vehicle cv;
	GetCarCharIsUsing(Scripting::GetPlayerPed(),&cv);
	f32 cH = 1000.0f;
	cH = GetEngineHealth(cv);
	f32 hDif = 1.0f;
	if(cH != NULL && cH < carHealth){
		if(cH == 0)
			hDif = 1000.0f;
		else
			hDif = (1000.0f/cH)*50;
	}
	carHealth = cH;
	if(carHealth<=150.0f){
		clearTarget();
		pedManager.cleanUp();
		taxiNoFareTimer = TimerA()+10000;
		setState(STATE_MISSIONS_STARTED_NO_PED);
		return;
	}
	else if(carHealth<=300.0f){
		taxiDescTimer = 0;
		displayText("Your car is trashed. Get it repaired.",1);
		displaySpray();
	}
	else{
		stopSpray();
	}
	if(tipPercent > 0.0f){
		tipPercent -= (tipDecrement * hDif * 0.5f);	
		drawTip();
	}
}

//void CustomFiberThread::nitro(){
//	if(TimerA() < nextNitro)
//		return;
//	nextNitro = TimerA()+1000;
//	Car currentCar;
//	GetCarCharIsUsing(Scripting::GetPlayerPed(),&currentCar);
//	f32 curspd;
//	f32 forwardX;
//	Scripting::GetCarSpeed(currentCar,&curspd);
//	Scripting::GetCarForwardX(currentCar,&forwardX);
//	if(Scripting::IsVehicleOnAllWheels(currentCar)){
//		Scripting::SetCarForwardSpeed(currentCar,-curspd*1.20f*forwardX);
//	}
//}

int CustomFiberThread::loadSaved()
{
	std::string line;
	std::ifstream myfile ("taxi.cfg");
	if (myfile.is_open())
	{
		if (! myfile.eof() )
		{
			getline (myfile,line);
		}
		else{
			return -1;
		}
		myfile.close();
	}
	else{
		return -1;
	}
	return atoi(line.c_str());
}

void CustomFiberThread::save( int toSave )
{
	std::ofstream file("taxi.cfg",std::ifstream::binary);
	char buffer[200];
	_itoa_s(toSave,buffer,200,10);
	file.write(buffer,(int)floor((float)toSave/10.0f)+1);

	file.close();
}

void CustomFiberThread::RunScript()
{

	if(loadSaved() == -1){
		save(0);
	}
	SetTimerA(0);

	while(IsThreadAlive())
	{
		Wait(5);

		checkKeys();
		update();
	}
}