#include <iostream>
#include <ctime>
#include <fstream>
#include <vector>
#include <string>
#include "coordManager.h"
#include "coord.h"
#include "Scripting.h"

using namespace std;
int curCoord = -1;

CoordManager::CoordManager()
{
	sprays = vector<Coord>();
	sprays.push_back(Coord(3,-1300.40881f,272.92273f,10.29829f,""));
	sprays.push_back(Coord(3,-1148.46582f,1175.47412f,16.40753f,""));
	sprays.push_back(Coord(2,-308.27817f,1547.28870f,20.02279f,""));
	sprays.push_back(Coord(2,-512.80359f,378.20111f,6.27826f,""));
	sprays.push_back(Coord(1,1057.43298f,-286.17682f,20.92082f,""));
	coords = vector<Coord>();
}

const Coord CoordManager::getClosestSpray() const //gets the nearest spray paint shop
{
	u32 unlockedMaps = Scripting::GetIntStat((Scripting::eIntStatistic)363); //STAT_ISLANDS_UNLOCKED
	vector<Coord> availableSprayCoordinates = vector<Coord>();
	for(int i=0;i<(int)sprays.size();i++){
		if(unlockedMaps>=sprays.at(i).getIslandID()){ //can access this part of the map
			availableSprayCoordinates.push_back(sprays.at(i));
		}
	}

	f32 pX,pY,pZ;
	int closestCoord = 0;
	Scripting::GetCharCoordinates(Scripting::GetPlayerPed(),&pX,&pY,&pZ);
	for(int j=0;j<(int)availableSprayCoordinates.size();j++){
		f32 cX,cY,cZ;
		f32 cX2,cY2,cZ2;
		f32 dist,dist2;
		availableSprayCoordinates.at(closestCoord).getCoord(&cX,&cY,&cZ);
		availableSprayCoordinates.at(j).getCoord(&cX2,&cY2,&cZ2);
		Scripting::GetDistanceBetweenCoords3D(pX,pY,pZ,cX,cY,cZ,&dist);
		Scripting::GetDistanceBetweenCoords3D(pX,pY,pZ,cX2,cY2,cZ2,&dist2);
		if(dist2<dist){
			closestCoord = j;
		}
	}
	return availableSprayCoordinates.at(closestCoord);
}

CoordManager::~CoordManager()
{

}

Coord CoordManager::nextCoord(){ //for debugging only
	curCoord++;
	return coords.at(curCoord%(int)coords.size());
}

const Coord CoordManager::getRandomCoord( int money ) const
{
	u32 unlmap = Scripting::GetIntStat((Scripting::eIntStatistic)363); //unlocked maps
	srand((unsigned int)time((time_t)NULL));
	vector<Coord> availableCoords = vector<Coord>();
	if(money == NULL || money < 2){
		money = 2;
	}
	int gameMoney = money * 5;
	float moneyPerDistance = 0.05f;
	int random_integer;
	for(int i=0;i<(int)coords.size();i++){
		f32 pX,pY,pZ;
		f32 cX,cY,cZ;
		f32 dist;
		Coord cc = coords.at(i);
		cc.getCoord(&cX,&cY,&cZ);
		Scripting::GetCharCoordinates(Scripting::GetPlayerPed(),&pX,&pY,&pZ);
		Scripting::GetDistanceBetweenCoords3D(pX,pY,pZ,cX,cY,cZ,&dist);
		if(dist<=0)
			dist *= -1;
		if(dist>100.0f && (dist*(1+(2/((rand()%4)+1))))<gameMoney/moneyPerDistance && unlmap>=cc.getIslandID()) //the target is far enough and we can access the part of the map and 
			availableCoords.push_back(coords.at(i));
	}
	if((int)availableCoords.size()<1){ //no available coords? pick one at random, then
		availableCoords = vector<Coord>();
		for(int i=0;i<(int)coords.size();i++){
			Coord cc = coords.at(i);
			if(unlmap>=cc.getIslandID()){
				availableCoords.push_back(coords.at(i));
			}
		}
	}
	random_integer = rand()%(int)availableCoords.size();
	return availableCoords.at(random_integer);
}

void CoordManager::parseFile(const char *filename){
	vector<string> lines = vector<string>();
	string line;
	ifstream myfile (filename);
	int islandID;
	char areaname[100];
	if (myfile.is_open())
	{
		while (! myfile.eof() )
		{
			getline (myfile,line);
			lines.push_back(line);
		}
		myfile.close();
	}
	for(int i=0;i<(int)lines.size();i++){
		string s = lines.at(i);
		if(s.size()<2 || s.at(0) == ';'){
			continue;
		}
		if(s.at(0) == '#'){
			islandID = atoi(s.substr(8,1).c_str());
		}
		else if(s.at(0) == '$'){
			strcpy_s(areaname,100,s.substr(1).c_str());
		}
		else{
			float x,y,z;
			char description[400];
			char * buf;
			string delim = "|";
			char s2[300];
			strcpy_s(s2,300,s.c_str());
			char *nexttoken;
			buf = strtok_s(s2,delim.c_str(),&nexttoken);//x
			x = (float)atof(buf);
			buf = strtok_s(nexttoken,delim.c_str(),&nexttoken);
			y = (float)atof(buf);
			buf = strtok_s(nexttoken,delim.c_str(),&nexttoken);
			z = (float)atof(buf);
			buf = strtok_s(nexttoken,delim.c_str(),&nexttoken);
			sprintf_s(description,400,"%s, %s",buf,areaname);
			coords.push_back(Coord(islandID,x,y,z,description));
		}
	}
}

int CoordManager::numCoords() const
{
	return (int)coords.size();
}

void CoordManager::placeCoords(){
	coords.push_back(Coord(1,1319.105f,-610.379f,12.183f,"the retirement home on Shinnecock Ave., Beachgate"));
	coords.push_back(Coord(1,1255.890f,-613.943f,13.781f,"the retirement home on Shinnecock Ave., Beachgate"));
	coords.push_back(Coord(1,1340.737f,-846.938f,7.855f,"Shinnecock Ave., Beachgate"));
	coords.push_back(Coord(1,1405.067f,-807.075f,7.856f,"Claiborne St., Beachgate"));
	coords.push_back(Coord(1,1331.883f,-687.160f,7.932f,"Shinnecock Ave, Beachgate"));
	coords.push_back(Coord(1,1184.944f,381.241f,24.135f,"the Clucking Bell on Huntington St., Cerveza Heights"));
	coords.push_back(Coord(1,1232.038f,512.272f,28.097f,"the Dukes Police Station on Livingston St., Cerveza Heights"));
	coords.push_back(Coord(1,1138.604f,435.318f,29.209f,"the fish market on Dukes Blvd., Cerveza Heights"));
	coords.push_back(Coord(1,1129.706f,327.354f,29.304f,"the RON gas station on Dukes Blvd., Cerveza Heights"));
	coords.push_back(Coord(1,1367.670f,421.501f,23.204f,"the grocery Store on Charleston Ave., Cerveza Heights"));
	coords.push_back(Coord(1,1337.253f,328.269f,19.918f,"Thornton St., Cerveza Heights"));
	coords.push_back(Coord(1,1025.038f,171.980f,31.523f,"Munsee Ave., Downtown Broker"));
	coords.push_back(Coord(1,1053.180f,108.505f,32.823f,"the gun shop on Dillon St., Downtown Broker"));
	coords.push_back(Coord(1,1108.988f,37.484f,33.520f,"the Pizza Salad Bar on Montauk Ave., Downtown Broker"));
	coords.push_back(Coord(1,1329.616f,-461.656f,15.288f,"the Apartment Building on Cody St., Firefly Projects"));
	coords.push_back(Coord(1,1218.266f,-375.130f,20.446f,"the Apartment Building on James St., Firefly Projects"));
	coords.push_back(Coord(1,1213.717f,-262.725f,22.988f,"the Apartment Building on Onondaga Ave., Firefly Projects"));
	coords.push_back(Coord(1,1196.953f,-511.106f,13.525f,"the basketball court on Onondaga Ave., Firefly Projects"));
	coords.push_back(Coord(1,1282.471f,-250.874f,25.289f,"the playground on Saponi Ave., Firefly Projects"));
	coords.push_back(Coord(1,1376.574f,-251.164f,19.808f,"the playground on Mohengan Ave., Firefly Projects"));
	coords.push_back(Coord(1,949.549f,-643.560f,13.812f,"Funland on Wappinger Ave., Firefly Island"));
	coords.push_back(Coord(1,1088.337f,-650.671f,12.911f,"the docks on Oneida Ave., Firefly Island"));
	coords.push_back(Coord(1,881.017f,-472.822f,14.527f,"the 69th Street Diner on Bart St., Hove Beach"));
	coords.push_back(Coord(1,1137.680f,-358.767f,18.800f,"the RON gas station on Kid St., Hove Beach"));
	coords.push_back(Coord(1,994.979f,-479.231f,15.501f,"Wappinger Ave., Hove Beach"));
	coords.push_back(Coord(1,903.134f,-444.373f,15.273f,"the Russian clothing shop on Mohawk Ave., Hove Beach"));
	coords.push_back(Coord(1,994.994f,-544.531f,14.371f,"the Hove Beach train terminal on Wappinger Ave., Hove Beach"));
	coords.push_back(Coord(1,1110.210f,-563.627f,13.010f,"the Smirt World on Crockett Ave., Hove Beach"));
	coords.push_back(Coord(1,902.796f,-492.285f,14.801f,"Comrades Bar on Mohawk Ave., Hove Beach"));
	coords.push_back(Coord(1,920.874f,-534.529f,13.998f,"the phone booth on Mohawk Ave., Hove Beach"));
	coords.push_back(Coord(1,901.171f,-350.871f,17.271f,"the South Broker LCPD station on Oakley St., Hove Beach"));
	coords.push_back(Coord(1,958.185f,-308.072f,19.195f,"the Perestroika Cabaret Club on Tulsa St., Hove Beach"));
	coords.push_back(Coord(1,838.986f,-549.287f,13.475f,"the phone booth on Iroquois Ave., Hove Beach"));
	coords.push_back(Coord(1,829.056f,-391.174f,13.538f,"the Spin on This Laundromat on Iroquois Ave., Hove Beach"));
	coords.push_back(Coord(1,994.979f,-479.231f,15.501f,"Wappinger Ave., Hove Beach"));
	coords.push_back(Coord(1,1127.054f,-49.768f,35.726f,"Sundance St., Outlook"));
	coords.push_back(Coord(1,1101.807f,-91.873f,35.789f,"Soldier's Plaza on Montauk Ave., Outlook"));
	coords.push_back(Coord(1,1048.078f,-265.875f,20.923f,"the Outlook Park entrance on Gibson St., Outlook"));
	coords.push_back(Coord(1,982.456f,-169.278f,23.665f,"the Tw@ internet cafe on Oneida Ave., Outlook"));
	coords.push_back(Coord(1,1060.387f,-275.754f,20.774f,"Native Auto Parts on Gibson St., Outlook"));
	coords.push_back(Coord(1,1327.673f,-215.875f,22.853f,"Mohegan Ave., South Slopes"));
	coords.push_back(Coord(1,1348.916f,-137.492f,22.647f,"Jeff's Liquor and Wine on Hickock St., South Slopes"));
	coords.push_back(Coord(1,1173.312f,-225.722f,23.192f,"the PhillPharm on Deadwood St., South Slopes"));
	coords.push_back(Coord(1,1300.211f,-32.448f,27.960f,"the Schottler subway entrance on Cayuga Ave., South Slopes"));
	coords.push_back(Coord(1,1426.909f,20.609f,25.581f,"the BAY bar on Boone St., Beachwood City"));
	coords.push_back(Coord(1,1482.950f,57.551f,24.435f,"the Homebrew Cafe, Beachwood City"));
	coords.push_back(Coord(1,1445.926f,147.819f,24.352f,"the Live Nudes Bar on Cassidy St., Beachwood City"));
	coords.push_back(Coord(1,1659.313f,239.988f,24.625f,"the Burger Shot on Carson St., Beachwood City"));
	coords.push_back(Coord(1,774.560f,122.400f,5.606f,"Mohanet Ave., Boabo"));
	coords.push_back(Coord(1,817.858f,217.936f,5.644f,"the parking lot on Mohanet Ave., Boabo"));
	coords.push_back(Coord(1,951.694f,458.208f,14.907f,"the Creek St Diner on Creek St., Boabo"));
	coords.push_back(Coord(1,855.901f,325.965f,5.540f,"Chicory St, Boabo"));
	coords.push_back(Coord(1,723.262f,95.118f,5.474f,"the construction site on Mohanet Ave., Boabo"));
	coords.push_back(Coord(1,794.833f,44.685f,5.570f,"the Betta building on Mohanet Ave., Boabo"));
	coords.push_back(Coord(1,774.973f,179.069f,5.560f,"the RON gas station on Mohanet Ave., Boabo"));
	coords.push_back(Coord(1,830.861f,301.099f,5.561f,"Mohanet Ave., Boabo"));
	coords.push_back(Coord(1,808.664f,421.444f,11.522f,"the wharehouse on Mohanet Ave., Boabo"));
	coords.push_back(Coord(1,854.729f,-122.609f,5.602f,"Brucies Executive Lifestyle Autos on Mohanet Ave., East Hook"));
	coords.push_back(Coord(1,788.628f,-169.507f,5.617f,"the Broker Navy Yard on Deleware Ave., East Hook"));
	coords.push_back(Coord(1,834.512f,-74.169f,5.5532f,"AEEF Refridgeration Equipment on Mohanet Ave., East Hook"));
	coords.push_back(Coord(1,1260.673f,719.651f,36.180f,"the PillPharm on Dukes Blvd., East Island City"));
	coords.push_back(Coord(1,1248.677f,584.028f,38.044f,"the South Broker LCPD station on Bunker Hill Ave., East Island City"));
	coords.push_back(Coord(1,1268.757f,599.312f,37.996f,"the LC24 Tower on Bunker Hill Ave., East Island City"));
	coords.push_back(Coord(1,1014.809f,555.307f,22.001f,"the Hotel on Hooper St., East Island City"));
	coords.push_back(Coord(1,986.319f,547.176f,21.833f,"the Auto Back garage on Hooper St., East Island City"));
	coords.push_back(Coord(1,1250.673f,719.651f,36.180f,"the PillPharm on Dukes Blvd., East Island City"));
	coords.push_back(Coord(1,2355.826f,375.121f,5.557f,"the main airport entrance on the Algonquin - Dukes Expressway, Francis International Airport"));
	coords.push_back(Coord(1,2278.674f,314.092f,5.552f,"the airport parking ramp on the Broker - Dukes Expressway, Francis International Airport"));
	coords.push_back(Coord(1,2424.872f,311.319f,5.579f,"the rear airport entrance on the Algonquin - Dukes Expressway, Francis International Airport"));
	coords.push_back(Coord(1,3422.686f,472.500f,5.562f,"the rear airport entrance on the Algonquin - Dukes Expressway, Francis International Airport"));
	coords.push_back(Coord(1,2320.974f,490.590f,5.586f,"the taxi platform on the Algonquin - Dukes Expressway, Francis International Airport"));
	coords.push_back(Coord(1,1249.291f,422.183f,28.611f,"Ellery St., Meadow Hills"));
	coords.push_back(Coord(1,1565.743f,468.781f,28.595f,"Stillwater Ave., Meadow Hills"));
	coords.push_back(Coord(1,1609.899f,747.917f,27.406f,"the mansion on Tudor St., Meadow Hills"));
	coords.push_back(Coord(1,1401.858f,623.030f,33.472f,"Savannah Ave., Meadows Park"));
	coords.push_back(Coord(1,1402.155f,529.969f,28.486f,"Savannah Ave., Meadows Park"));
	coords.push_back(Coord(1,1594.250f,898.658f,15.682f,"the Monoglobe on Stillwater Ave., Meadows Park"));
	coords.push_back(Coord(1,1752.026f,859.558f,15.859f,"the RON gas station on Cleves Ave., Meadows Park"));
	coords.push_back(Coord(1,1542.348f,890.856f,15.575f,"the baseball diamond on Tudor St., Meadows Park"));
	coords.push_back(Coord(1,1488.720f,773.192f,27.918f,"the tennis court on Walton Ln., Meadows Park"));
	coords.push_back(Coord(1,919.067f,132.501f,35.103f,"the park on Mohawk Ave., Rotterdam Hill"));
	coords.push_back(Coord(1,931.179f,179.135f,31.703f,"Mohawk Ave., Rotterdam Hill"));
	coords.push_back(Coord(1,848.270f,35.381f,25.583f,"the park on Asparagus Ave., Rotterdam Hill"));
	coords.push_back(Coord(1,897.641f,-33.832f,26.888f,"Onion St., Rotterdam Hill"));
	coords.push_back(Coord(1,944.735f,109.814f,34.626f,"the Broker LCFD on Dillion St., Rotterdam Hill"));
	coords.push_back(Coord(1,1343.477f,60.325f,31.615f,"the Meat Market on Cayuga Ave., Schottler"));
	coords.push_back(Coord(1,1376.527f,154.518f,27.165f,"the 99 Cent Store on Cayuga Ave., Schottler"));
	coords.push_back(Coord(1,1308.031f,249.747f,36.354f,"the Turning You On store on Carson St., Schottler"));
	coords.push_back(Coord(1,1190.771f,189.895f,32.079f,"the Schottler Medical Center on Cassidy St., Schottler"));
	coords.push_back(Coord(1,1326.324f,183.883f,27.550f,"Cassidy St., Schottler"));
	coords.push_back(Coord(1,1233.852f,1010.117f,13.131f,"Gantry Park on Dukes Dr., Steinway"));
	coords.push_back(Coord(1,996.889f,981.438f,17.402f,"the park entrance on Dukes Dr., Steinway"));
	coords.push_back(Coord(1,969.562f,827.287f,24.888f,"Concord Ave., Steinway"));
	coords.push_back(Coord(1,1178.397f,837.149f,35.641f,"the apartment complex on Yorktown Ave., Steinway"));
	coords.push_back(Coord(1,1044.397f,836.505f,31.225f,"Trenton Ave., Steinway"));
	coords.push_back(Coord(1,1178.773f,740.493f,35.522f,"the Steinway Beer Garden on Yorktown Ave., Steinway"));
	coords.push_back(Coord(1,1163.971f,767.218f,35.461f,"the basket ball court on Morris St., Steinway"));
	coords.push_back(Coord(1,1804.411f,721.919f,25.308f,"the Community Center on Tudor St., Willis"));
	coords.push_back(Coord(1,1707.822f,490.244f,28.595f,"Big Als Furniture Wharehouse on Howard St., Willis"));
	coords.push_back(Coord(1,1814.392f,587.816f,28.594f,"the Pizza This restaurant on Saratoga Ave., Willis"));
	coords.push_back(Coord(1,1837.430f,348.816f,22.169f,"the Willis Car Wash on Saratoga Ave., Willis"));
	coords.push_back(Coord(1,622.397f,1764.014f,37.674f,"1655 Grand Blvd., Boulevard"));
	coords.push_back(Coord(1,785.868f,1846.360f,38.924f,"1666 Grand Blvd., Boulevard"));
	coords.push_back(Coord(1,410.757f,1886.107f,22.512f,"the tennis court on Uprock St., Boulevard"));
	coords.push_back(Coord(1,482.655f,1892.093f,22.531f,"the park entrance on Uprock St., Boulevard"));
	coords.push_back(Coord(1,343.110f,1829.315f,17.285f,"Butterfly St., Boulevard"));
	coords.push_back(Coord(1,736.972f,1380.750f,13.773f,"S&M Auto Sales on Guantanamo Ave., Chase point"));
	coords.push_back(Coord(1,791.802f,1428.230f,13.804f,"Auto Radiator Auto Sales on Spin St., Chase point"));
	coords.push_back(Coord(1,746.372f,1448.346f,13.787f,"the Windmill St. Subway entrance on Guantanamo Ave., Chase point"));
	coords.push_back(Coord(1,705.227f,1488.485f,14.194f,"the Auto Shop on Windmill St., Chase point"));
	coords.push_back(Coord(1,544.273f,1733.355f,31.780f,"the Furniture Store on Elbow St., Fortside"));
	coords.push_back(Coord(1,362.775f,1614.891f,15.741f,"the apartment complex on San Quentin Ave., Fortside"));
	coords.push_back(Coord(1,441.611f,1526.937f,15.852f,"the Burger Shot on San Quentin Ave., Fortside"));
	coords.push_back(Coord(1,433.544f,1649.528f,15.569f,"the 99 Cent Store on Mill St., Fortside"));
	coords.push_back(Coord(1,736.604f,1523.847f,16.899f,"the Windmill St. Subway entrance on Guantanamo Ave., Industrial"));
	coords.push_back(Coord(1,736.520f,155.297f,21.668f,"the Belly Deli on Guantanamo Ave., Industrial"));
	coords.push_back(Coord(1,1346.414f,1648.193f,16.167f,"the PillPharm on Alcatraz Ave., Industrial"));
	coords.push_back(Coord(1,1095.737f,1599.531f,16.223f,"the Burger Shot on Drill St., Industrial"));
	coords.push_back(Coord(1,1186.100f,1615.645f,16.176f,"Leavenworth Ave., Industrial"));
	coords.push_back(Coord(1,972.660f,1812.212f,19.600f,"the Medical and Dental Center on Leavenworth Ave., Industrial"));
	coords.push_back(Coord(1,1419.682f,1720.024f,16.394f,"the RON gas station on Sing Sing Ave., Little Bay"));
	coords.push_back(Coord(1,1285.343f,1663.596f,16.224f,"the Nail Salon on Coxsack Ave., Little Bay"));
	coords.push_back(Coord(1,1335.737f,1709.812f,16.214f,"the Tabacco Shop on Bronco St., Little Bay"));
	coords.push_back(Coord(1,1276.479f,1791.607f,9.968f,"Coxsack Ave., Little Bay"));
	coords.push_back(Coord(1,1346.466f,1686.531f,16.235f,"the Hardware store on Alcatraz Ave., Little Bay"));
	coords.push_back(Coord(1,1110.704f,1883.343f,11.874f,"the apartment complex on Planche St., Northern Gardens"));
	coords.push_back(Coord(1,1130.683f,1718.617f,10.023f,"the Bohan FDLC station on Worm St., Northern Gardens"));
	coords.push_back(Coord(1,1216.411f,1711.562f,16.134f,"The Triangle Club on Bronco St., Northern Gardens"));
	coords.push_back(Coord(1,972.495f,1869.714f,22.587f,"the East Bohan LCPD station on Leavenworth Ave., Northern Gardens"));
	coords.push_back(Coord(1,1159.213f,1790.213f,10.426f,"the apartment complex on Caterpillar St., Northern Gardens"));
	coords.push_back(Coord(1,503.637f,1448.542f,9.484f,"the Drug store Hollowback St., South Bohan"));
	coords.push_back(Coord(1,445.463f,1452.939f,9.451f,"the apartment complex on San Quentin Ave., South Bohan"));
	coords.push_back(Coord(1,580.194f,1399.611f,10.472f,"the Grocery Store on Joliet St., South Bohan"));
	coords.push_back(Coord(1,686.369f,1431.205f,14.015f,"the Electronics Store on Attica Ave., South Bohan"));
	coords.push_back(Coord(1,590.023f,1494.061f,14.097f,"Joliet St., South Bohan"));
	coords.push_back(Coord(2,-585.357f,-154.199f,6.027f,"the parking lot on Castle Dr., Castle Garden City"));
	coords.push_back(Coord(2,-489.534f,-236.240f,7.417f,"the Globe gas station on Feldspar St., Castle Garden City"));
	coords.push_back(Coord(2,-528.330f,-333.836f,5.583f,"the park entrance on Castle Dr., Castle Garden City"));
	coords.push_back(Coord(2,-494.227f,-337.178f,5.758f,"Castle Dr., Castle Garden City"));
	coords.push_back(Coord(2,-599.998f,-250.693f,6.524f,"Castle Dr., Castle Garden City"));
	coords.push_back(Coord(2,-615.724f,-201.843f,6.588f,"Castle Dr., Castle Garden City"));
	coords.push_back(Coord(2,-397.858f,-451.947f,4.451f,"the Pier on Castle Dr., Castle Garden City"));
	coords.push_back(Coord(2,-180.699f,-781.535f,4.730f,"Union Drive West, Castle Gardens"));
	coords.push_back(Coord(2,-37.153f,-318.151f,14.243f,"the Video Game center on Emerald St., Chinatown"));
	coords.push_back(Coord(2,61.205f,-339.857f,14.268f,"Body Canvas Tattoos on Bismarck Ave., Chinatown"));
	coords.push_back(Coord(2,132.578f,-401.922f,14.238f,"Uncle E Jewellery on Diamond St., Chinatown"));
	coords.push_back(Coord(2,32.290f,497.472f,14.312f,"Ranch on Calcium St., Chinatown"));
	coords.push_back(Coord(2,-13.137f,-492.122f,14.289f,"the Bank of Liberty on Calcium St., Chinatown"));
	coords.push_back(Coord(2,61.183f,-379.427f,14.273f,"Big Wang Restaurant on Bismarck Ave., Chinatown"));
	coords.push_back(Coord(2,-219.084f,-567.455f,4.471f,"the Emergency Room on Union Drive West, City Hall"));
	coords.push_back(Coord(2,-126.987f,-375.412f,14.279f,"Denver Ave., City Hall"));
	coords.push_back(Coord(2,-136.472f,-364.508f,14.276f,"Denver Ave., City Hall"));
	coords.push_back(Coord(2,-140.060f,-499.172f,14.251f,"Calcium St., City Hall"));
	coords.push_back(Coord(2,-211.460f,-593.582f,4.454f,"the parking lot on Union Drive West, City Hall"));
	coords.push_back(Coord(2,97.779f,1257.557f,15.253f,"the LCPD station on San Juan RD., East Holland"));
	coords.push_back(Coord(2,0.929f,1346.357f,17.407f,"Vauxite St., East Holland"));
	coords.push_back(Coord(2,-146.675f,1357.200f,19.946f,"the Super Deli on Denver Ave., East Holland"));
	coords.push_back(Coord(2,-265.717f,1360.750f,24.805f,"MODO Clothing Store on Exeter Ave., East Holland"));
	coords.push_back(Coord(2,-266.538f,1293.825f,24.244f,"the Movie Pit on Exeter Ave., East Holland"));
	coords.push_back(Coord(2,-68.021f,1336.784f,19.938f,"the apartment colplex on Vauxite St., East Holland"));
	coords.push_back(Coord(2,17.926f,-108.973f,14.290f,"Leopolds on Bismarck Ave., Easton"));
	coords.push_back(Coord(2,23.055f,-46.441f,14.347f,"Hematite St., Easton"));
	coords.push_back(Coord(2,27.523f,-92.672f,14.289f,"Squid Row Budget Seafood Restaurant on Bismarck Ave., Easton"));
	coords.push_back(Coord(2,95.684f,143.081f,14.226f,"the Emergency Room on Jade St., Easton"));
	coords.push_back(Coord(2,226.708f,-229.377f,8.592f,"the Fishmarket North LCPD station on Privateer Rd., Fishmarket North"));
	coords.push_back(Coord(2,229.182f,-270.786f,8.581f,"the Brown Stripe Wash&Dry on Borlock RD., Fishmarket North"));
	coords.push_back(Coord(2,331.944f,-260.079f,4.063f,"the Wharehouse on Union Drive East, Fishmarket North"));
	coords.push_back(Coord(2,342.014f,-532.620f,4.203f,"Pier 45 on Flatfish Plaice, Fishmarket North"));
	coords.push_back(Coord(2,344.754f,-432.471f,4.165f,"the LC Garbage on Flatfish Plaice, Fishmarket North"));
	coords.push_back(Coord(2,292.708f,-336.359f,4.456f,"the Fish Market South Fire Department on Privateer RD., Fishmarket North"));
	coords.push_back(Coord(2,259.359f,-306.047f,6.660f,"the Storage Center on Emerald St., Fishmarket North"));
	coords.push_back(Coord(2,118.556f,556.838f,14.135f,"Jerkovs Cossieurs Bar on Albany Ave., Hatton Gardens"));
	coords.push_back(Coord(2,118.530f,519.650f,14.110f,"the Bank of Liberty on Albany Ave., Hatton Gardens"));
	coords.push_back(Coord(2,118.526f,438.366f,14.205f,"Africa Tower on Albany Ave., Hatton Gardens"));
	coords.push_back(Coord(2,157.790f,369.232f,14.659f,"the U.N. Building on Lorimar St., Hatton Gardens"));
	coords.push_back(Coord(2,-9.184f,389.607f,14.268f,"the Church on Lorimar St., Hatton Gardens"));
	coords.push_back(Coord(2,45.720f,420.351f,14.197f,"Panoramic on Bismarck Ave, Hatton Gardens"));
	coords.push_back(Coord(2,34.548f,981.289f,14.155f,"the SuperStar Cafe on Bismarck Ave., Lancaster"));
	coords.push_back(Coord(2,106.873f,1156.982f,14.274f,"the gas station on Topaz St., Lancaster"));
	coords.push_back(Coord(2,85.268f,1177.393f,14.312f,"the Westminster LCPD station on Topaz St., Lancaster"));
	coords.push_back(Coord(2,1.200f,1178.569f,14.273f,"Topaz St., Lancaster"));
	coords.push_back(Coord(2,118.887f,980.685f,14.231f,"Skeeza Clothing Store on Albany Ave., Lancaster"));
	coords.push_back(Coord(2,187.860f,149.099f,14.403f,"the parking lot on Jade St., Lancet"));
	coords.push_back(Coord(2,118.460f,298.548f,6.106f,"Albany Ave., Lancet"));
	coords.push_back(Coord(2,33.375f,340.432f,14.189f,"Bismarck Ave., Lancet"));
	coords.push_back(Coord(2,-147.622f,-299.049f,14.293f,"the Beer and Liquor store on Emerald St., Little Italy"));
	coords.push_back(Coord(2,-126.746f,-262.293f,12.159f,"Drusillas Italian Garden on Denver Ave., Little Italy"));
	coords.push_back(Coord(2,-198.886f,-250.706f,14.188f,"the Food Center on Brown Place, Little Italy"));
	coords.push_back(Coord(2,145.343f,-218.376f,14.297f,"the Fishmarket South LCPD station on Albany Ave., Lower Easton"));
	coords.push_back(Coord(2,99.642f,-168.666f,14.078f,"Pawn Star on Garnet St., Lower Easton"));
	coords.push_back(Coord(2,65.613f,-229.541f,14.320f,"the PillPharm on Feldspar St., Lower Easton"));
	coords.push_back(Coord(2,50.299f,-229.111f,14.265f,"the 24/7 Supermarket on Feldspar St., Lower Easton"));
	coords.push_back(Coord(2,-38.753f,959.576f,14.234f,"the Grand Northumbrian Hotel on Columbus Ave., Middle Park"));
	coords.push_back(Coord(2,-38.624f,889.105f,14.213f,"Columbus Ave., Middle Park"));
	coords.push_back(Coord(2,-60.367f,812.389f,14.218f,"The Libertonian Museum on Columbus Ave., Middle Park"));
	coords.push_back(Coord(2,-61.942f,1154.137f,14.244f,"the East Middle Park entrance on Topaz St., Middle Park"));
	coords.push_back(Coord(2,-38.924f,661.729f,14.193f,"MissT clothing shop on Columbus Ave., Middle Park"));
	coords.push_back(Coord(2,118.559f,641.901f,14.216f,"the 60 Diner on Albany Ave., Middle Park East"));
	coords.push_back(Coord(2,43.736f,810.220f,14.197f,"Grotti Dealership on Bismarck Ave., Middle Park East"));
	coords.push_back(Coord(2,79.471f,665.635f,14.151f,"the LCPD station on Obsidian St., Middle Park East"));
	coords.push_back(Coord(2,-38.369f,1124.901f,14.257f,"Columbus Ave., Middle Park East"));
	coords.push_back(Coord(2,-5.069f,616.510f,14.169f,"Gaulle on Nickel St., Middle Park East"));
	coords.push_back(Coord(2,-96.972f,616.516f,14.300f,"The Amissary Hotel on Nickel St., Middle Park East"));
	coords.push_back(Coord(2,-166.427f,616.570f,14.325f,"The Majestic Hotel on Nickel St., Middle Park East"));
	coords.push_back(Coord(2,-350.399f,627.503f,14.195f,"the Middle Park South West Entrance on Nickel St., Middle Park East"));
	coords.push_back(Coord(2,-353.104f,1039.361f,14.233f,"the Middle Park West entrance on Frankfort Ave., Middle Park West"));
	coords.push_back(Coord(2,-469.795f,859.731f,9.496f,"Male Nails Salon on Pyrite St., Middle Park West"));
	coords.push_back(Coord(2,-548.048f,887.267f,9.442f,"Ivy Drive South, Middle Park West"));
	coords.push_back(Coord(2,-554.399f,872.760f,9.443f,"the Middle Park Entrance on Ivy Drive South, Middle Park West"));
	coords.push_back(Coord(2,-559.145f,633.684f,6.207f,"the Skate Park on Union Drive West, Middle Park West"));
	coords.push_back(Coord(2,-346.833f,1392.471f,12.666f,"Tw@t on Frankfort Ave., North Holland"));
	coords.push_back(Coord(2,-532.351f,1345.883f,16.981f,"the Linen Lounge on Vauxite St., North Holland"));
	coords.push_back(Coord(2,-347.856f,1234.325f,20.981f,"Frankfort Ave., North Holland"));
	coords.push_back(Coord(2,-458.740f,1360.445f,16.966f,"the Meat Factory on Galveston Ave., North Holland"));
	coords.push_back(Coord(2,-119.125f,1424.266f,19.921f,"the apartment complex on Wardite St., Northwood"));
	coords.push_back(Coord(2,-346.844f,1432.576f,11.783f,"the Frankfort High subway entrance on Frankfort Ave., Northwood"));
	coords.push_back(Coord(2,-305.332f,1571.410f,20.023f,"Auto Cowboys Garage on Frankfort Ave., Northwood"));
	coords.push_back(Coord(2,-480.612f,1525.999f,18.341f,"the apartment complex on Galveston Ave., Northwood"));
	coords.push_back(Coord(2,-256.996f,1456.686f,19.951f,"the basket ball court on Exeter Ave., Northwood"));
	coords.push_back(Coord(2,-483.912f,1712.397f,8.106f,"RustySchit Salvage on Grummer RD., Northwood"));
	coords.push_back(Coord(2,118.495f,43.143f,14.272f,"the Bean Machine on Albany Ave., Presidents City"));
	coords.push_back(Coord(2,233.790f,-45.701f,14.239f,"the apartment complex on President Ave., Presidents City"));
	coords.push_back(Coord(2,119.245f,-68.527f,14.267f,"the PillPharm on Albany Ave., Presidents City"));
	coords.push_back(Coord(2,-448.808f,363.936f,9.875f,"the Barber Shop on Galveston Ave., Purgatory"));
	coords.push_back(Coord(2,-509.823f,382.465f,6.238f,"Auto Limbo on West Way, Purgatory"));
	coords.push_back(Coord(2,-499.218f,473.318f,6.327f,"the Highspeed Highway Car Wash on Hell Gate, Purgatory"));
	coords.push_back(Coord(2,-458.184f,450.236f,9.385f,"the parking lot on Galveston Ave., Purgatory"));
	coords.push_back(Coord(2,-605.078f,565.537f,4.299f,"Broker Produce on Hematite Ave., Purgatory"));
	coords.push_back(Coord(2,-59.585f,507.742f,14.272f,"the Observation Desk on Columbus Ave., Star Junction"));
	coords.push_back(Coord(2,-60.271f,426.874f,14.186f,"Live Central on Columbus Ave., Star Junction"));
	coords.push_back(Coord(2,-133.898f,389.465f,14.289f,"the Seagull on Lorimar St., Star Junction"));
	coords.push_back(Coord(2,-192.787f,359.991f,14.323f,"Thespian Theaters on Denver-Exeter Ave., Star Junction"));
	coords.push_back(Coord(2,-192.566f,291.808f,14.350f,"Burger Shot on Denver-Exeter Ave., Star Junction"));
	coords.push_back(Coord(2,-169.052f,155.296f,14.277f,"Liberty Sports Network on Burlesque, Star Junction"));
	coords.push_back(Coord(2,-213.552f,181.289f,14.139f,"ME TV Theater on Denver-Exeter Ave., Star Junction"));
	coords.push_back(Coord(2,-324.888f,250.601f,14.304f,"Liberty Cameras on Kunzite St., Star Junction"));
	coords.push_back(Coord(2,-278.777f,518.755f,14.362f,"PUMP Sports Club on Burlesque, Star Junction"));
	coords.push_back(Coord(2,-353.435f,181.706f,14.332f,"Split Sides Comedy Club on Frankfort Ave., Star Junction"));
	coords.push_back(Coord(2,-267.989f,-280.723f,13.908f,"the Church on Liberty Lane, Suffolk"));
	coords.push_back(Coord(2,-258.559f,-252.789f,14.102f,"the Superb DELI on Liberty Lane, Suffolk"));
	coords.push_back(Coord(2,-309.113f,-229.364f,12.707f,"Suffolk Curios on Feldspar St., Suffolk"));
	coords.push_back(Coord(2,-386.511f,-229.752f,12.310f,"the clothing shop on Feldspar St., Suffolk"));
	coords.push_back(Coord(2,-472.172f,-232.667f,7.543f,"the Globe Oil gas station on Feldspar St., Suffolk"));
	coords.push_back(Coord(2,-334.709f,-168.918f,14.125f,"the Cafe on Garnet St., Suffolk"));
	coords.push_back(Coord(2,-35.688f,-562.639f,14.247f,"EE on Barium St., The Exchange"));
	coords.push_back(Coord(2,-62.508f,-639.747f,14.240f,"Al Dentes Restaurant on Amethyst St., The Exchange"));
	coords.push_back(Coord(2,11.287f,-651.474f,14.276f,"Perseus on Amethyst St., The Exchange"));
	coords.push_back(Coord(2,80.347f,-651.457f,12.144f,"the law offices of Goldberg, Ligner & Shyster on Amethyst St., The Exchange"));
	coords.push_back(Coord(2,156.279f,-563.807f,14.095f,"the Hair Salon on Barium St., The Exchange"));
	coords.push_back(Coord(2,6.879f,-610.670f,14.271f,"the Bank of Liberty on Amsterdam Lane, The Exchange"));
	coords.push_back(Coord(2,38.058f,-564.119f,14.294f,"Barium St., The Exchange"));
	coords.push_back(Coord(2,-451.221f,120.365f,9.378f,"the Superb DELI on Gaveston Ave., The Meat Quarter"));
	coords.push_back(Coord(2,-451.063f,-21.049f,9.369f,"the RON gas station on Galveston Ave., The Meat Quarter"));
	coords.push_back(Coord(2,-621.365f,-77.324f,4.557f,"the Golden Pier on Hematite St., The Meat Quarter"));
	coords.push_back(Coord(2,-120.702f,-25.008f,14.272f,"the Subway Station in The Triangle on Burlesque, The Triangle"));
	coords.push_back(Coord(2,-214.157f,-25.882f,14.285f,"the Bean Machine on Denver-Exeter Ave., The Triangle"));
	coords.push_back(Coord(2,-214.163f,73.770f,14.278f,"the SuperStar Cafe on Denver-Exeter Ave., The Triangle"));
	coords.push_back(Coord(2,-99.679f,32.378f,14.319f,"the Bean Machine on Iron St., The Triangle"));
	coords.push_back(Coord(2,-301.958f,23.304f,14.257f,"Wigwam Burger on Iron St., The Triangle"));
	coords.push_back(Coord(2,-353.148f,82.558f,14.341f,"Al Dentes Italian Restaurant on Frankfort Ave. , The Triangle"));
	coords.push_back(Coord(2,-60.317f,-75.943f,14.270f," Viendemente Restaurant on Columbus Ave., The Triangle"));
	coords.push_back(Coord(2,-558.184f,1094.279f,9.479f,"Silicon St., Varsity Heights"));
	coords.push_back(Coord(2,-429.088f,1178.588f,12.629f,"ther Burger Shot on Topaz St., Varsity Heights"));
	coords.push_back(Coord(2,-416.153f,1094.968f,11.330f,"the LCPD station on Silicon St., Varsity Heights"));
	coords.push_back(Coord(2,-495.652f,928.703f,9.446f,"Quartz St., Varsity Heights"));
	coords.push_back(Coord(2,-584.058f,1139.745f,9.454f,"the parking lot on Ivy Drive North, Varsity Heights"));
	coords.push_back(Coord(2,-406.060f,271.543f,12.724f,"the LCPD station on Kunzite St., Westminster"));
	coords.push_back(Coord(2,-390.505f,250.526f,14.033f,"the 60 Diner on Kunzite St., Westminster"));
	coords.push_back(Coord(2,-460.741f,223.429f,9.367f,"the FMA parking lot on Galveston Ave., Westminster"));
	coords.push_back(Coord(2,-615.107f,159.519f,4.282f,"the Burger Shot on Hematite St., Westminster"));
	coords.push_back(Coord(2,-609.492f,220.642f,4.282f,"Hoop City on Hematite St., Westminster"));
	coords.push_back(Coord(3,-1388.323f,532.039f,12.000f,"Dr. Craig Restaurant & DELI on Mueri St., Acter"));
	coords.push_back(Coord(3,-1504.661f,405.478f,19.039f,"North Tudor Medical Center on Babbage Dr., Acter"));
	coords.push_back(Coord(3,-1562.699f,429.297f,23.427f,"Edison Ave., Acter"));
	coords.push_back(Coord(3,-1633.151f,411.063f,24.941f,"Vitullo Ave., Acter"));
	coords.push_back(Coord(3,-1775.842f,361.186f,24.948f,"Aspdin Ave., Acter"));
	coords.push_back(Coord(3,-1731.684f,240.868f,20.428f,"the park entrance on Vitullo Ave., Acter"));
	coords.push_back(Coord(3,-1775.373f,363.254f,24.943f,"Aspdin Ave., Acter"));
	coords.push_back(Coord(3,-1787.415f,340.837f,24.949f,"Aspdin Ave., Acter"));
	coords.push_back(Coord(3,-1711.875f,274.820f,21.460f,"the Leftwood LCPD station on Vitullo Ave., Acter"));
	coords.push_back(Coord(3,-1606.061f,252.786f,14.363f,"Sinclair Ave., Acter"));
	coords.push_back(Coord(3,-1597.065f,340.488f,24.124f,"Schneider Ave., Acter"));
	coords.push_back(Coord(3,-1514.038f,-585.891f,2.456f,"the Wharehouse on Praetorian Ave., Acter Industrial Park"));
	coords.push_back(Coord(3,-1402.197f,-646.488f,2.460f,"the Wharehouse on Praetorian Ave., Acter Industrial Park"));
	coords.push_back(Coord(3,-1509.488f,-646.137f,2.455f,"the Wharehouse on Praetorian Ave., Acter Industrial Park"));
	coords.push_back(Coord(3,-1477.467f,-578.399f,2.457f,"the Wharehouse parking lot on Praetorian Ave., Acter Industrial Park"));
	coords.push_back(Coord(3,-1521.550f,-566.563f,2.457f,"the Wharehouse on Praetorian Ave., Acter Industrial Park"));
	coords.push_back(Coord(3,-1253.277f,-534.244f,2.545f,"the abandoned Wharehouse on Muskteer Ave., Acter Industrial Park"));
	coords.push_back(Coord(3,-1048.917f,-579.514f,2.467f,"the parking lot on Storax Rd., Acter Industrial Park"));
	coords.push_back(Coord(3,-1075.609f,-585.100f,2.464f,"the loading dock on Storax Rd., Acter Industrial Park"));
	coords.push_back(Coord(3,-1005.812f,-487.738f,2.556f,"the Alderney State Correctional Facility parking lot, Acter Industrial Park"));
	coords.push_back(Coord(3,-1159.061f,-375.936f,2.390f,"the Alderney State Correctional Facility main gate, Acter Industrial Park"));
	coords.push_back(Coord(3,-1009.834f,-313.301f,2.538f,"the storage yard on Grommet St., Acter Industrial Park"));
	coords.push_back(Coord(3,-1052.209f,-276.222f,2.535f,"the Coffee and Soda shop on Toggle Ave., Acter Industrial Park"));
	coords.push_back(Coord(3,-1346.041f,857.598f,19.135f,"the SchlongberSachs building on Koresh Square, Alderney City"));
	coords.push_back(Coord(3,-1209.999f,980.645f,19.136f,"Jonestown Ave., Alderney City"));
	coords.push_back(Coord(3,-1162.226f,908.397f,19.066f,"the Beauty Supply store on Jonestown Ave., Alderney City"));
	coords.push_back(Coord(3,-1098.416f,784.068f,18.864f,"the Discount Furniture store on Asahara Rd., Alderney City"));
	coords.push_back(Coord(3,-962.962f,787.803f,3.772f,"the Heli Pad on Rand Ave., Alderney City"));
	coords.push_back(Coord(3,-935.336f,839.664f,9.838f,"Rand Ave., Alderney City"));
	coords.push_back(Coord(3,-875.733f,1049.289f,19.402f,"Family Jewels on Applewhite St., Alderney City"));
	coords.push_back(Coord(3,-902.950f,1036.587f,20.102f,"International Online Unlimited on Rand Ave., Alderney City"));
	coords.push_back(Coord(3,-977.467f,1118.261f,15.801f,"the Copy Store on Hubbard Ave., Alderney City"));
	coords.push_back(Coord(3,-1025.422f,1071.132f,13.115f,"the Closeout Wharehouse on Mahesh Ave., Alderney City"));
	coords.push_back(Coord(3,-1039.410f,1118.156f,13.122f,"the Laundromat on Hubbard Ave., Alderney City"));
	coords.push_back(Coord(3,-1177.145f,1118.200f,13.145f,"Alderney Travel on Hubbard Ave., Alderney City"));
	coords.push_back(Coord(3,-1250.228f,1069.795f,19.247f,"Mr. Fuk's Rice Box on Lyndon Ave., Alderney City"));
	coords.push_back(Coord(3,-1468.984f,1035.293f,22.565f,"Deedee's Bargain Center on Lockowski Ave., Alderney City"));
	coords.push_back(Coord(3,-1468.964f,1118.314f,22.549f,"AutoEroticar on Lockowski Ave., Alderney City"));
	coords.push_back(Coord(3,-1339.580f,1036.850f,19.079f,"Lyndon Ave., Alderney City"));
	coords.push_back(Coord(3,-1501.951f,487.727f,19.081f,"Babbage Drive, Berchem"));
	coords.push_back(Coord(3,-1661.832f,536.682f,25.305f,"Aspdin Drive, Berchem"));
	coords.push_back(Coord(3,-1660.702f,609.283f,28.050f,"Aspdin Drive, Berchem"));
	coords.push_back(Coord(3,-1678.069f,638.161f,28.984f,"Lile Dry Cleaning on Aspdin Drive, Berchem"));
	coords.push_back(Coord(3,-1632.638f,780.805f,29.441f,"the storage center on Aspdin Drive, Berchem"));
	coords.push_back(Coord(3,-1436.683f,837.611f,19.071f,"McMahon Electronics on Vitullo Ave., Berchem"));
	coords.push_back(Coord(3,-1579.767f,579.834f,24.954f,"Wigwam on Vitullo Ave., Berchem"));
	coords.push_back(Coord(3,-1589.583f,614.852f,24.952f,"Vitullo Ave., Berchem"));
	coords.push_back(Coord(3,-1624.400f,686.184f,26.807f,"Cockerell Ave., Berchem"));
	coords.push_back(Coord(3,-1681.368f,673.070f,29.388f,"the phone booth on Aspdin Drive, Berchem"));
	coords.push_back(Coord(3,-1368.995f,1300.172f,21.314f,"the park on Manzano Rd., Leftwood"));
	coords.push_back(Coord(3,-1252.299f,1321.911f,21.202f,"Gozushi Restaraunt on Manzano Rd., Leftwood"));
	coords.push_back(Coord(3,-1233.699f,1382.695f,21.534f,"Bridger St., Leftwood"));
	coords.push_back(Coord(3,-1047.529f,1412.876f,23.961f,"the FMA parking lot on Sacramento Ave., Leftwood"));
	coords.push_back(Coord(3,-1467.556f,1393.544f,12.665f,"Checkout! Grocery Store on Beaverhead Ave., Leftwood"));
	coords.push_back(Coord(3,-1529.021f,1413.263f,12.666f,"Leftwood Sports Shop on Beaverhead Ave., Leftwood"));
	coords.push_back(Coord(3,-1303.291f,1290.022f,21.235f,"Westdyke Memorial Hospital on Long John Ave., Leftwood"));
	coords.push_back(Coord(3,-1256.233f,1246.815f,21.252f,"the Squid Row Restaurant on Long John Ave., Leftwood"));
	coords.push_back(Coord(3,-1181.751f,1379.681f,21.704f,"RANCH Restaurant on Bridger St., Leftwood"));
	coords.push_back(Coord(3,-1155.700f,1389.301f,23.882f,"Pizza This Restaurant on Bridger St., Leftwood"));
	coords.push_back(Coord(3,-1087.385f,472.212f,4.004f,"the Port Tudor Dock entrance on Asahara Rd., Normandy"));
	coords.push_back(Coord(3,-1024.136f,432.825f,3.991f,"the Port Tudor Dock on Asahara Rd., Normandy"));
	coords.push_back(Coord(3,-1127.326f,470.794f,3.995f,"the PostOP side entrance on Asahara Rd., Normandy"));
	coords.push_back(Coord(3,-1127.484f,404.587f,3.987f,"the PostOP main entrance on Asahara Rd., Normandy"));
	coords.push_back(Coord(3,-1202.370f,483.209f,3.995f,"Alpha Mail Couriers on Strower Ave., Normandy"));
	coords.push_back(Coord(3,-1246.816f,460.474f,4.286f,"the Port Tudor main entrance on Strower Ave., Normandy"));
	coords.push_back(Coord(3,-1216.694f,-229.189f,2.504f,"the West District LCPD station on Grommet St., Port Tudor"));
	coords.push_back(Coord(3,-1189.479f,-193.019f,3.482f,"Port Tudor storage docks on Grommet St., Port Tudor"));
	coords.push_back(Coord(3,-1100.552f,-128.965f,3.862f,"Port Tudor storage docks on Barsac Ave., Port Tudor"));
	coords.push_back(Coord(3,-1290.471f,210.087f,8.629f,"Roebuck Rd., Port Tudor"));
	coords.push_back(Coord(3,-1301.271f,255.720f,10.342f,"Axels on Hardtack Ave., Port Tudor"));
	coords.push_back(Coord(3,-1349.839f,276.886f,10.778f,"531 Odhner Ave., Port Tudor"));
	coords.push_back(Coord(3,-1125.771f,280.465f,4.005f,"Liberty State Delivery on Asahara Rd., Port Tudor"));
	coords.push_back(Coord(3,-1216.130f,226.553f,4.053f,"the Reception Office on Asahara Rd., Port Tudor"));
	coords.push_back(Coord(3,-1379.958f,21.870f,6.601f,"the Globe Oil gas station on Latchkey Ave., Tudor"));
	coords.push_back(Coord(3,-1596.606f,115.722f,12.131f,"the wharehouse on Argus St., Tudor"));
	coords.push_back(Coord(3,-1607.322f,32.714f,9.381f,"Honkers Strip Club on Tinderbox Ave., Tudor"));
	coords.push_back(Coord(3,-1463.454f,-14.129f,6.540f,"Emery St., Tudor"));
	coords.push_back(Coord(3,-1479.398f,118.965f,8.559f,"Niblick St., Tudor"));
	coords.push_back(Coord(3,-2063.816f,-99.918f,6.231f,"the damaged tug boat on Hardtack Ave., Tudor"));
	coords.push_back(Coord(3,-2195.889f,-73.042f,6.258f,"the park on Hardtack Ave., Tudor"));
	coords.push_back(Coord(3,-2177.799f,2.135f,6.668f,"the phone booth on Hardtack Ave., Tudor"));
	coords.push_back(Coord(3,-2128.695f,185.177f,12.217f,"the FDLC station on Hardtack Ave., Tudor"));
	coords.push_back(Coord(3,-1057.011f,1418.259f,23.975f,"the Leftwood Church on Sacramento Ave., Westdyke"));
	coords.push_back(Coord(3,-1057.315f,1472.545f,23.969f,"Westdyke Autos on Sacramento Ave., Westdyke"));
	coords.push_back(Coord(3,-1039.411f,1533.711f,23.943f,"Sacramento Ave., Westdyke"));
	coords.push_back(Coord(3,-993.998f,1594.043f,23.433f,"the Burger Shot on Sacramento Ave., Westdyke"));
	coords.push_back(Coord(3,-931.127f,1499.701f,24.232f,"the Liquor Store on Sacramento Ave., Westdyke"));
	coords.push_back(Coord(3,-961.663f,1871.297f,22.127f,"the old mansion on Beaverhead Ave., Westdyke"));
	coords.push_back(Coord(3,-1164.583f,1881.101f,6.282f,"the old restaurant  on Beaverhead Ave., Westdyke"));
	coords.push_back(Coord(3,-1511.112f,1418.831f,12.666f,"the Fanny Crabs Restaurant on Beaverhead Ave., Westdyke"));
	coords.push_back(Coord(3,-1363.651f,1457.558f,21.251f,"Flathead Road, Westdyke"));
	//parseFile("coords.txt");
}