#include "taxiPed.h"
#include "Scripting.h"
#include <math.h>
#include <ctime>
#include <iostream>

u32 nextSpeak = 0;
u32 nextFlight = 0;
int airtime = 0;
int upsidedowntime = 0;

TaxiPed::TaxiPed(){
	pedState = PEDSTATE_NOT_FACING_PLAYER;
}

void TaxiPed::setPed(Scripting::Ped p){
	ped = p;
	Scripting::AddBlipForChar(ped,&blip);
	Scripting::ChangeBlipColour(blip,5);
}

void TaxiPed::getPed( Scripting::Ped *p ) const
{
	*p = ped;
}

bool TaxiPed::isBad() const
{
	if(badness)
		return true;
	if(!Scripting::DoesCharExist(ped))
		return true;
	if(Scripting::IsCharDead(ped) || Scripting::IsCharOnFire(ped))
		return true;
	return false;
}
void TaxiPed::cleanUp(){
	if(Scripting::DoesBlipExist(blip))
		Scripting::RemoveBlip(blip);

	if(Scripting::DoesCharExist(ped)){
		badness = true;
		Scripting::SetCharWillFlyThroughWindscreen(ped,true);
		if(Scripting::IsCharInAnyCar(ped)){
			Scripting::Car cv2;
			Scripting::GetCarCharIsUsing(ped,&cv2);
			Scripting::TaskLeaveCar(ped,cv2);
		}
		if(!Scripting::IsCharInAnyCar(ped)){
			friendly(false);
			f32 pedX,pedY,pedZ;
			Scripting::GetCharCoordinates(ped,&pedX,&pedY,&pedZ);
			Scripting::ClearCharTasksImmediately(ped);
			if(Scripting::DoesScenarioExistInArea(pedX,pedY,pedZ,50.0f,1))
				Scripting::TaskUseNearestScenarioToPos(ped,pedX,pedY,pedZ,50.0f); //yay, details!
			else{
				Scripting::TaskWanderStandard(ped);
			}
			Scripting::Ped p = Scripting::Ped();
			ped = p;
			badness = false;
			setState(PEDSTATE_NOT_FACING_PLAYER);
		}
	}
	else{
		badness = false;
		setState(PEDSTATE_NOT_FACING_PLAYER);
	}
}
void TaxiPed::friendly( b8 b ) const
{
	if(!Scripting::DoesCharExist(ped) )
		return;
	if(b){
		if(!Scripting::IsPedInGroup(ped)){
			Scripting::Group pGroup;
			Scripting::GetPlayerGroup(Scripting::GetPlayer(),&pGroup);
			Scripting::SetGroupMember(pGroup,ped);
		}
	}
	else{
		Scripting::RemoveCharFromGroup(ped);
	}
}
void TaxiPed::setState(int s){
	if(pedState == s){
		return;
	}
	pedState = s;
}
int TaxiPed::getState() const
{
	return pedState;
}

void TaxiPed::update(){
	if(isBad()){
		cleanUp();
		return;
	}

	Scripting::Car cv;
	Scripting::GetCarCharIsUsing(Scripting::GetPlayerPed(), &cv);
	f32 pedX,pedY,pedZ;
	if(Scripting::DoesCharExist(ped)){
		Scripting::GetCharCoordinates(ped,&pedX,&pedY,&pedZ);
	}

	switch(pedState){
		case PEDSTATE_NOT_FACING_PLAYER://ped outside. not facing player.
			if(Scripting::DoesCharExist(ped))
			{
				f32 playerX,playerY,playerZ;
				Scripting::GetCharCoordinates(Scripting::GetPlayerPed(),&playerX,&playerY,&playerZ);
				f32 dist;
				Scripting::GetDistanceBetweenCoords3D(pedX,pedY,pedZ,playerX,playerY,playerZ,&dist);
				if(dist<10.0f){
					f32 carSpeed;
					if(Scripting::DoesVehicleExist(cv)){
						Scripting::GetCarSpeed(cv,&carSpeed);
						if(carSpeed<1.0f){ //slow enough.
							//Scripting::TaskStandStill(ped,0);
							f32 pedHeading,playerHeading;
							Scripting::GetCharHeading(ped,&pedHeading);
							Scripting::GetCharHeading(Scripting::GetPlayerPed(),&playerHeading);
							f32 headingOffset = playerHeading-pedHeading; //check nearest side of car
							if(headingOffset<0.0f)
								headingOffset += 360;
							if(headingOffset>180.0f)
								Scripting::TaskEnterCarAsPassenger(ped, cv, 99999, 2);
							else
								Scripting::TaskEnterCarAsPassenger(ped, cv, 99999, 1);

							if(Scripting::DoesBlipExist(blip))
								Scripting::RemoveBlip(blip);
							setState(PEDSTATE_MOVING_TO_TAXI);
							break;
						}
					}
				}
				if(!Scripting::IsCharFacingChar(ped,Scripting::GetPlayerPed(),1.0f)){ //turn them to face the driver
					f32 x,y,z,x1,y1,z1;
					Scripting::GetCharCoordinates(Scripting::GetPlayerPed(),&x1,&y1,&z1);
					Scripting::GetCharCoordinates(ped,&x,&y,&z);
					//if(y1-y!=0)
					f32 at = atan2((y1-y),(x1-x)) * 180 / PI;
					at -= 90;
					Scripting::SetCharHeading(ped,at);
				}
				//else{
				//if(!Scripting::IsCharUsingScenario(ped,"Scenario_WaitingForTaxi"))
				//	Scripting::TaskStartScenarioInPlace(ped,"Scenario_WaitingForTaxi");
				//}

				if(Scripting::HaveAnimsLoaded("AMB@TAXI_HAIL_M") && Scripting::HaveAnimsLoaded("AMB@TAXI_HAIL_F")){ //more details!!

					if(Scripting::IsCharMale(ped)){
						if(Scripting::IsCharPlayingAnim(ped, "AMB@TAXI_HAIL_M", "HAIL_LEFT"))
							if(!Scripting::HasCharAnimFinished(ped, "AMB@TAXI_HAIL_M", "HAIL_LEFT"))
								break;
						if(!Scripting::IsAmbientSpeechPlaying(ped))
							Scripting::SayAmbientSpeech(ped,"TAXI_HAIL",true,false,false);
						Scripting::TaskPlayAnim(ped,"HAIL_LEFT", "AMB@TAXI_HAIL_M", 8.0f, 0, 1, 1, 0, -2);
					}
					else{
						if(Scripting::IsCharPlayingAnim(ped, "AMB@TAXI_HAIL_F", "HAIL_LEFT"))
							if(!Scripting::HasCharAnimFinished(ped, "AMB@TAXI_HAIL_F", "HAIL_LEFT"))
								break;
						if(!Scripting::IsAmbientSpeechPlaying(ped))
							Scripting::SayAmbientSpeech(ped,"TAXI_HAIL",true,false,false);
						Scripting::TaskPlayAnim(ped,"HAIL_LEFT", "AMB@TAXI_HAIL_F", 8.0f, 0, 1, 1, 0, -2);
					}
				}
			}
			break;
		case PEDSTATE_MOVING_TO_TAXI: 
			if(Scripting::DoesCharExist(ped)){
				if(Scripting::IsCharGettingInToACar(ped) || Scripting::IsCharInAnyCar(ped))
					friendly(true);
				if(Scripting::IsCharInAnyCar(ped)){
					nextSpeak = Scripting::TimerA()+5000;
					Scripting::SayAmbientSpeech(ped,"GENERIC_HI",true,false,false);
					Scripting::SetCharWillFlyThroughWindscreen(ped,false);
					setState(PEDSTATE_INSIDE_TAXI);
				}
			}
			break;
		case PEDSTATE_INSIDE_TAXI:

			if(Scripting::DoesCharExist(ped)){
				if(!Scripting::IsCharInAnyCar(ped)){
					cleanUp();
					break;
				}
				friendly(true); //make sure they don't attack the player...
				if(nextSpeak < Scripting::TimerA() && !Scripting::IsAmbientSpeechPlaying(ped)){
					if(Scripting::GetTimeSincePlayerHitPed(Scripting::GetPlayer())<1){

						Scripting::SayAmbientSpeech(ped,"TAXI_HIT_PED",true,false,false);
						if(!Scripting::IsAmbientSpeechPlaying(ped)){
							for(int c=0;c<5;c++){
								switch(rand()%20){
									case 0:
										break;
									case 1:
										Scripting::SayAmbientSpeech(ped,"SHIT",true,false,false); //yes, the game has this string
										break;
									case 2:
										Scripting::SayAmbientSpeech(ped,"DODGE",true,false,false);
										break;
									case 3:
										Scripting::SayAmbientSpeech(ped,"SHOCKED",true,false,false);
								}
								if(Scripting::IsAmbientSpeechPlaying(ped))
									break;
							}
						}
						nextSpeak = Scripting::TimerA()+5000; //silence for 5s
					}
					else if(Scripting::GetTimeSincePlayerHitCar(Scripting::GetPlayer())<=1 || Scripting::GetTimeSincePlayerHitBuilding(Scripting::GetPlayer())<= 1 ){
						//for(int c=0;c<5;c++){
						switch(rand()%20){
							case 0:
								Scripting::SayAmbientSpeech(ped,"SHIT",true,false,false);
								break;
							case 1:
								Scripting::SayAmbientSpeech(ped,"DODGE",true,false,false);
								break;
							case 2:
								Scripting::SayAmbientSpeech(ped,"SHOCKED",true,false,false);
								break;
						}
										//if(Scripting::IsAmbientSpeechPlaying(ped))
										//break;
										//}
						nextSpeak = Scripting::TimerA()+5000;
					}
				}
				if(nextFlight < Scripting::TimerA()){
					if(Scripting::DoesVehicleExist(cv)){
						if(Scripting::IsCarInAirProper(cv)){
							airtime++;
							if(airtime>100){ //woooooo!
								Scripting::CancelCurrentlyPlayingAmbientSpeech(ped);
								Scripting::SayAmbientSpeech(ped,"SURPRISED",true,false,false);
								nextSpeak = Scripting::TimerA()+5000;
							}
						}
						else{
							airtime = 0;
						}
					}
				}

				if(Scripting::DoesVehicleExist(cv)){
					if(Scripting::IsCarUpsidedown(cv)){
						f32 spd;
						Scripting::GetCarSpeed(cv,&spd);
						if(spd<5.0f){
							if(upsidedowntime < 100){
								upsidedowntime++;
							}
							else{
								Scripting::CancelCurrentlyPlayingAmbientSpeech(ped); //shut up, ped
								cleanUp();
							}
						}else
							upsidedowntime = 0;
					}
					else
						upsidedowntime = 0;
				}
			}
			break;
	}
}
TaxiPed::~TaxiPed(){
	//if(Scripting::DoesBlipExist(blip))
	//	Scripting::RemoveBlip(blip);
}